"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LoggerController = void 0;
var _xstate = require("xstate");
var _dateFns = require("date-fns");
var _reactNative = require("react-native");
var _axios = require("../config/axios");
/**
 * The function fetchDeviceInfo retrieves information about the device, including the brand, model, and
 * operating system version.
 * @returns The function `fetchDeviceInfo` returns a Promise that resolves to an object of type
 * `DeviceInfo`.
 */
const fetchDeviceInfo = () => {
  const iOS = _reactNative.Platform.OS === 'ios';
  if (iOS) {
    const {
      constants,
      isPad
    } = _reactNative.Platform;
    return {
      brand: 'Apple',
      model: isPad ? 'iPad' : 'iPhone',
      os_version: constants.osVersion
    };
  }
  const {
    constants
  } = _reactNative.Platform;
  return {
    brand: constants.Brand,
    model: constants.Model,
    os_version: constants.Fingerprint
  };
};

/**
 * The function `sendLog` sends log data to a server using a POST request.
 * @param {LoggerContext} context - The `context` parameter is an object that contains various
 * information related to logging. Here's a breakdown of the properties:
 * @returns The function `sendLog` returns a `Promise<void>`.
 */
const sendLog = async context => {
  const {
    content
  } = context;
  if (!content) return;
  const payload = {
    environment: context.environment,
    client_uuid: context.clientUUID,
    user_id: context.userID,
    timestamp: (0, _dateFns.format)(new Date(), "yyyy-MM-dd'T'HH:mm:ss'Z'"),
    platform: _reactNative.Platform.OS,
    device_info: context.deviceInfo,
    sdk: context.sdkInfo
  };
  if (content.server_response) payload.transmission_log = content;else payload.extraction_log = content;
  await _axios.loggerClient.post('/', payload);
};
const LoggerController = exports.LoggerController = (0, _xstate.createMachine)({
  id: 'LoggerController',
  initial: 'waiting',
  predictableActionArguments: true,
  context: {
    clientUUID: '',
    content: null,
    deviceInfo: null,
    environment: 'development',
    sdkInfo: null,
    timestamp: (0, _dateFns.format)(new Date(), "yyyy-MM-dd'T'HH:mm:ss'Z'"),
    userID: ''
  },
  states: {
    waiting: {
      on: {
        init: {
          target: 'idle',
          actions: ['handleInit']
        }
      }
    },
    idle: {
      on: {
        send: {
          target: 'sending',
          actions: (0, _xstate.assign)({
            content: (_, event) => event.payload
          })
        }
      }
    },
    sending: {
      invoke: {
        id: 'sendLog',
        src: sendLog,
        onDone: {
          target: 'idle'
        },
        onError: {
          target: 'idle',
          actions: (0, _xstate.assign)((context, event) => {
            console.log(JSON.stringify(event.data));
            return {
              ...context
            };
          })
        }
      }
    }
  }
}, {
  actions: {
    handleInit: (0, _xstate.assign)((context, event) => {
      if (event.type !== 'init') return {
        ...context
      };
      const deviceInfo = fetchDeviceInfo();
      return {
        ...context,
        environment: event.payload.environment,
        clientUUID: event.payload.clientUUID,
        userID: event.payload.userID || '',
        sdkInfo: event.payload.sdkInfo,
        deviceInfo
      };
    })
  }
});
//# sourceMappingURL=LoggerController.js.map